<?php
// $Id: ezmlm.php,v 1.6 2005/02/24 17:04:00 turbo Exp $
//
require("./include/pql_config.inc");
include($_SESSION["path"]."/header.html");
?>  
  <span class="title1">Ezmlm Mailinglist Control</span>

  <br><br>
Here you can manage your ezmlm mailinglists. Mailing lists have to be located under each domain's mail directory (baseMailDir in the domain object) and is organized per domain name in the list frame.<br>

  </body>
</html>

<?php
/*
 * Local variables:
 * mode: php
 * mode: font-lock
 * tab-width: 4
 * End:
 */
?>
